summaryrefslogtreecommitdiffstats
path: root/ksquirrel/imageedit/sq_imagebcg.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/imageedit/sq_imagebcg.ui.h')
-rw-r--r--ksquirrel/imageedit/sq_imagebcg.ui.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/ksquirrel/imageedit/sq_imagebcg.ui.h b/ksquirrel/imageedit/sq_imagebcg.ui.h
index 7d80c6f..3d0913d 100644
--- a/ksquirrel/imageedit/sq_imagebcg.ui.h
+++ b/ksquirrel/imageedit/sq_imagebcg.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
@@ -13,7 +13,7 @@ void SQ_ImageBCG::init()
{
m_inst = this;
- QPixmap p = QPixmap::fromMimeSource(locate("data", "images/imageedit/reset_value.png"));
+ TQPixmap p = TQPixmap::fromMimeSource(locate("data", "images/imageedit/reset_value.png"));
sQ_LabelB->setSingle(true);
sQ_LabelC->setSingle(true);
@@ -32,21 +32,21 @@ void SQ_ImageBCG::init()
pushResetGreen->setPixmap(p);
pushResetBlue->setPixmap(p);
- strings.append(QString("<b>") + tr2i18n("Brightness") + ",&nbsp;" + tr2i18n("Contrast") + ",&nbsp;" + tr2i18n("Gamma") + "</b>");
- strings.append(QString("<b>") + tr2i18n("Red") + ",&nbsp;" + tr2i18n("Green") + ",&nbsp;" + tr2i18n("Blue") + "</b>");
+ strings.append(TQString("<b>") + tr2i18n("Brightness") + ",&nbsp;" + tr2i18n("Contrast") + ",&nbsp;" + tr2i18n("Gamma") + "</b>");
+ strings.append(TQString("<b>") + tr2i18n("Red") + ",&nbsp;" + tr2i18n("Green") + ",&nbsp;" + tr2i18n("Blue") + "</b>");
id = 0;
widgetStackParams->raiseWidget(id);
text->setText(strings[id]);
- QPixmap tool1 = QPixmap::fromMimeSource(locate("data", "images/imageedit/resize_toolbutton.png"));
- QPixmap tool2 = QPixmap::fromMimeSource(locate("data", "images/imageedit/resize_toolbutton2.png"));
+ TQPixmap tool1 = TQPixmap::fromMimeSource(locate("data", "images/imageedit/resize_toolbutton.png"));
+ TQPixmap tool2 = TQPixmap::fromMimeSource(locate("data", "images/imageedit/resize_toolbutton2.png"));
push1->setPixmap(tool1);
push2->setPixmap(tool2);
spinG->setRange(0, 6.0, 0.01, 2);
spinG->setValue(1.0);
- connect(spinG, SIGNAL(valueChanged(int)), spinG, SLOT(slotValueChanged(int)));
+ connect(spinG, TQT_SIGNAL(valueChanged(int)), spinG, TQT_SLOT(slotValueChanged(int)));
}
void SQ_ImageBCG::slotResetG()
@@ -177,9 +177,9 @@ void SQ_ImageBCG::slotGSpinChanged(double v)
changeImage(sliderB->value(), sliderC->value(), val, sliderRed->value(), sliderGreen->value(), sliderBlue->value());
}
-void SQ_ImageBCG::assignNewImage(const QImage &im)
+void SQ_ImageBCG::assignNewImage(const TQImage &im)
{
- QPixmap p;
+ TQPixmap p;
p.convertFromImage(im);
pixmap1->setPixmap(p);
}
@@ -219,14 +219,14 @@ void SQ_ImageBCG::slotPush()
text->setText(strings[id]);
}
-void SQ_ImageBCG::setPreviewImage(const QImage &im)
+void SQ_ImageBCG::setPreviewImage(const TQImage &im)
{
if(im.isNull()) return;
sample = im.copy();
sample_saved = sample.copy();
- QPixmap p;
+ TQPixmap p;
p.convertFromImage(sample_saved);
pixmap->setPixmap(p);
@@ -2,7 +2,7 @@
**
** If you wish to add, delete or rename functions or slots use
-** Qt Designer which will update this file, preserving your code. Create an
+** TQt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.